@@ -1,7 +1,7 @@
 /*
   form_func.c
 
-  Copyright 2009, 2010 Free Software Foundation, Inc.
+  Copyright 2009, 2010, 2014 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -26,11 +26,14 @@
 #if HAVE_CURSES_H
 #include <curses.h>
 #include <form.h>
-#endif
-
-#if HAVE_NCURSES_CURSES_H
+#elif HAVE_NCURSES_CURSES_H
 #include <ncurses/curses.h>
 #include <ncurses/form.h>
+#elif HAVE_NCURSESW_CURSES_H
+#include <ncursesw/curses.h>
+#include <ncursesw/form.h>
+#else
+#error "No curses.h file included"
 #endif
 
 #include "compat.h"
