@@ -1,7 +1,7 @@
 /*
   form_spec.c
 
-  Copyright 2009, 2010 Free Software Foundation, Inc.
+  Copyright 2009, 2010, 2014 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -28,11 +28,14 @@
 #if HAVE_CURSES_H
 #include <curses.h>
 #include <form.h>
-#endif
-
-#if HAVE_NCURSES_CURSES_H
+#elif HAVE_NCURSES_CURSES_H
 #include <ncurses/curses.h>
 #include <ncurses/form.h>
+#elif HAVE_NCURSESW_CURSES_H
+#include <ncursesw/curses.h>
+#include <ncursesw/form.h>
+#else
+#error "No curses.h file included"
 #endif
 
 #include "compat.h"
@@ -61,11 +64,11 @@ gucu_dup_field (SCM field, SCM toprow, SCM leftcol)
   if (c_dup == (FIELD *) NULL)
     {
       if (errno == E_BAD_ARGUMENT)
-        scm_out_of_range ("dup-field", scm_list_2 (toprow, leftcol));
+	scm_out_of_range ("dup-field", scm_list_2 (toprow, leftcol));
       else if (errno == E_SYSTEM_ERROR)
-        scm_syserror ("dup-field");
+	scm_syserror ("dup-field");
       else
-        abort ();
+	abort ();
     }
 
   return _scm_from_field (c_dup);
@@ -92,7 +95,7 @@ gucu_dynamic_field_info (SCM field)
     abort ();
 
   return scm_list_3 (scm_from_int (c_rows),
-                     scm_from_int (c_cols), scm_from_int (c_max));
+		     scm_from_int (c_cols), scm_from_int (c_max));
 }
 
 // Returns the contents of the field buffer BUFFER.  Only buffer 0 is
@@ -103,7 +106,7 @@ gucu_field_buffer (SCM field, SCM buffer)
 {
   SCM_ASSERT (_scm_is_field (field), field, SCM_ARG1, "field-buffer");
   SCM_ASSERT (SCM_UNBNDP (buffer)
-              || scm_is_integer (buffer), buffer, SCM_ARG2, "field-buffer");
+	      || scm_is_integer (buffer), buffer, SCM_ARG2, "field-buffer");
 
   FIELD *c_field = _scm_to_field (field);
   int c_buffer;
@@ -120,7 +123,7 @@ gucu_field_buffer (SCM field, SCM buffer)
   if (buf == NULL)
     {
       if (errno == E_BAD_ARGUMENT)
-        scm_out_of_range ("field-buffer", field);
+	scm_out_of_range ("field-buffer", field);
     }
 
   return (scm_from_locale_string (buf));
@@ -138,7 +141,7 @@ gucu_field_info (SCM field)
 
   c_field = _scm_to_field (field);
   ret = field_info (c_field, &c_rows, &c_cols,
-                    &c_frow, &c_fcol, &c_nrow, &c_nbuf);
+		    &c_frow, &c_fcol, &c_nrow, &c_nbuf);
 
   if (ret == E_BAD_ARGUMENT)
     scm_out_of_range ("field-info", field);
@@ -148,11 +151,11 @@ gucu_field_info (SCM field)
     abort ();
 
   return scm_list_n (scm_from_int (c_rows),
-                     scm_from_int (c_cols),
-                     scm_from_int (c_frow),
-                     scm_from_int (c_fcol),
-                     scm_from_int (c_nrow),
-                     scm_from_int (c_nbuf), SCM_UNDEFINED);
+		     scm_from_int (c_cols),
+		     scm_from_int (c_frow),
+		     scm_from_int (c_fcol),
+		     scm_from_int (c_nrow),
+		     scm_from_int (c_nbuf), SCM_UNDEFINED);
 
 }
 
@@ -216,11 +219,11 @@ gucu_link_field (SCM field, SCM toprow, SCM leftcol)
   if (c_link == (FIELD *) NULL)
     {
       if (errno == E_BAD_ARGUMENT)
-        scm_out_of_range ("link-field", scm_list_2 (toprow, leftcol));
+	scm_out_of_range ("link-field", scm_list_2 (toprow, leftcol));
       else if (errno == E_SYSTEM_ERROR)
-        scm_syserror ("link-field");
+	scm_syserror ("link-field");
       else
-        abort ();
+	abort ();
     }
 
   return _scm_from_field (c_link);
@@ -272,7 +275,8 @@ gucu_set_field_type_x (SCM field, SCM type, SCM a, SCM b, SCM c)
       c_width = scm_to_int (a);
       ret = set_field_type (c_field, TYPE_ALNUM, c_width);
     }
-  else if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_ALPHA"))))
+  else
+    if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_ALPHA"))))
     {
       int c_width;
 
@@ -280,7 +284,8 @@ gucu_set_field_type_x (SCM field, SCM type, SCM a, SCM b, SCM c)
       c_width = scm_to_int (a);
       ret = set_field_type (c_field, TYPE_ALPHA, c_width);
     }
-  else if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_ENUM"))))
+  else
+    if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_ENUM"))))
     {
       char **c_str_list;
       int c_case_sensitivity;
@@ -289,33 +294,34 @@ gucu_set_field_type_x (SCM field, SCM type, SCM a, SCM b, SCM c)
       size_t i;
 
       SCM_ASSERT (scm_is_true (scm_list_p (a)), a, SCM_ARG3,
-                  "set-field-type!");
+		  "set-field-type!");
       SCM_ASSERT (scm_is_integer (b), b, SCM_ARG4, "set-field-type!");
       SCM_ASSERT (scm_is_integer (c), c, SCM_ARG5, "set-field-type!");
 
       len = scm_to_size_t (scm_length (a));
       c_str_list =
-        scm_gc_malloc (sizeof (char *) * (len + 1), "set-field-type!");
+	scm_gc_malloc (sizeof (char *) * (len + 1), "set-field-type!");
       for (i = 0; i < len; i++)
-        {
-          c_str_list[i] = (scm_to_locale_string
-                           (scm_list_ref (a, scm_from_int (i))));
-        }
+	{
+	  c_str_list[i] = (scm_to_locale_string
+			   (scm_list_ref (a, scm_from_int (i))));
+	}
       c_str_list[len - 1] = (char *) 0;
       c_case_sensitivity = scm_to_int (b);
       c_partial = scm_to_int (c);
 
       ret =
-        set_field_type (c_field, TYPE_ENUM, c_str_list, c_case_sensitivity,
-                        c_partial);
+	set_field_type (c_field, TYPE_ENUM, c_str_list, c_case_sensitivity,
+			c_partial);
 
       for (i = 0; i < len; i++)
-        {
-          free (c_str_list[i]);
-        }
+	{
+	  free (c_str_list[i]);
+	}
       free (c_str_list);
     }
-  else if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_NUMERIC"))))
+  else if (scm_is_true (scm_eq_p (type,
+				  scm_from_locale_symbol ("TYPE_NUMERIC"))))
     {
       int c_precision;
       double c_min;
@@ -331,7 +337,8 @@ gucu_set_field_type_x (SCM field, SCM type, SCM a, SCM b, SCM c)
 
       ret = set_field_type (c_field, TYPE_NUMERIC, c_precision, c_min, c_max);
     }
-  else if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_REGEXP"))))
+  else
+    if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_REGEXP"))))
     {
       char *c_reg;
 
@@ -343,7 +350,8 @@ gucu_set_field_type_x (SCM field, SCM type, SCM a, SCM b, SCM c)
 
       free (c_reg);
     }
-  else if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_IPV4"))))
+  else
+    if (scm_is_true (scm_eq_p (type, scm_from_locale_symbol ("TYPE_IPV4"))))
     {
       ret = set_field_type (c_field, TYPE_IPV4);
     }
