@@ -1,7 +1,7 @@
 /*
   form_type.h
 
-  Copyright 2009, 2010 Free Software Foundation, Inc.
+  Copyright 2009, 2010, 2014 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -27,10 +27,12 @@
 
 #if HAVE_CURSES_H
 #include <form.h>
-#endif
-
-#if HAVE_NCURSES_CURSES_H
+#elif HAVE_NCURSES_CURSES_H
 #include <ncurses/form.h>
+#elif HAVE_NCURSESW_CURSES_H
+#include <ncursesw/form.h>
+#else
+#error "No curses.h file included"
 #endif
 
 struct gucu_form
