@@ -1,7 +1,7 @@
 /*
   type.c
 
-  Copyright 2009, 2010, 2011 Free Software Foundation, Inc.
+  Copyright 2009, 2010, 2011, 2014 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -32,10 +32,12 @@
 
 #if HAVE_CURSES_H
 #include <curses.h>
-#endif
-
-#if HAVE_NCURSES_CURSES_H
+#elif HAVE_NCURSES_CURSES_H
 #include <ncurses/curses.h>
+#elif HAVE_NCURSESW_CURSES_H
+#include <ncursesw/curses.h>
+#else
+#error "No curses.h file included"
 #endif
 
 #include "compat.h"
@@ -171,7 +173,7 @@ _scm_xchar_from_cchar (cchar_t * x)
       {
 	uint32_t cp;
 	ret = wchar_to_codepoint (wch[i], &cp);
-	if (!ret)
+	if (ret == 0)
 	  element = SCM_MAKE_CHAR (GUCU_REPLACEMENT_CODEPOINT);
 	else
 	  element = SCM_MAKE_CHAR (cp);
@@ -256,7 +258,7 @@ _scm_schar_from_wchar (wchar_t ch)
   uint32_t cp;
 
   ret = wchar_to_codepoint (ch, &cp);
-  if (!ret)
+  if (ret == 0)
     return SCM_BOOL_F;
 
   return SCM_MAKE_CHAR (cp);
@@ -873,7 +875,7 @@ int
 print_screen (SCM x, SCM port, scm_print_state * pstate UNUSED)
 {
   SCREEN *screen;
-  char *str;
+  char str[SIZEOF_VOID_P*2+3];
 
   /* Don't use _scm_is_screen in this assert, because it says freed screens aren't
      screens.  */
@@ -888,7 +890,7 @@ print_screen (SCM x, SCM port, scm_print_state * pstate UNUSED)
     }
   else
     {
-      if (asprintf (&str, "%p", (void *) screen) < 0)
+      if (snprintf (str, sizeof(str), "%p", (void *) screen) < 0)
 	scm_puts ("???", port);
       else
 	scm_puts (str, port);
@@ -1017,7 +1019,7 @@ int
 print_window (SCM x, SCM port, scm_print_state * pstate UNUSED)
 {
   WINDOW *win = (WINDOW *) SCM_SMOB_DATA (x);
-  char *str;
+  char str[SIZEOF_VOID_P*2+3];
 
   assert (SCM_SMOB_PREDICATE (window_tag, x));
 
@@ -1027,7 +1029,7 @@ print_window (SCM x, SCM port, scm_print_state * pstate UNUSED)
     scm_puts ("(freed)", port);
   else
     {
-      if (asprintf (&str, "%p", (void *) win) < 0)
+      if (snprintf (str, sizeof(str), "%p", (void *) win) < 0)
 	scm_puts ("???", port);
       else
 	scm_puts (str, port);
