@@ -1,7 +1,7 @@
 /*
   type.h
 
-  Copyright 2009, 2010, 2011 Free Software Foundation, Inc.
+  Copyright 2009, 2010, 2011, 2014 Free Software Foundation, Inc.
 
   This file is part of GNU Guile-Ncurses.
 
@@ -32,10 +32,12 @@
 
 #if HAVE_CURSES_H
 #include <curses.h>
-#endif
-
-#if HAVE_NCURSES_CURSES_H
+#elif HAVE_NCURSES_CURSES_H
 #include <ncurses/curses.h>
+#elif HAVE_NCURSESW_CURSES_H
+#include <ncursesw/curses.h>
+#else
+#error "No curses.h file included"
 #endif
 
 #include "visibility.h"
